==> huaweicloudsdkcbr-3.1.99-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/vault_create_parameters.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class VaultCreateParameters:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'combined_order': 'CombinedOrder'
    }

    attribute_map = {
        'combined_order': 'combined_order'
    }

    def __init__(self, combined_order=None):
        """VaultCreateParameters

        The model defined in huaweicloud sdk

        :param combined_order: 
        :type combined_order: :class:`huaweicloudsdkcbr.v1.CombinedOrder`
        """
        
        

        self._combined_order = None
        self.discriminator = None

        if combined_order is not None:
            self.combined_order = combined_order

    @property
    def combined_order(self):
        """Gets the combined_order of this VaultCreateParameters.

        :return: The combined_order of this VaultCreateParameters.
        :rtype: :class:`huaweicloudsdkcbr.v1.CombinedOrder`
        """
        return self._combined_order

    @combined_order.setter
    def combined_order(self, combined_order):
        """Sets the combined_order of this VaultCreateParameters.

        :param combined_order: The combined_order of this VaultCreateParameters.
        :type combined_order: :class:`huaweicloudsdkcbr.v1.CombinedOrder`
        """
        self._combined_order = combined_order

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VaultCreateParameters):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcbr-3.1.146-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/vault_create_parameters.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class VaultCreateParameters:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'combined_order': 'CombinedOrder'
    }

    attribute_map = {
        'combined_order': 'combined_order'
    }

    def __init__(self, combined_order=None):
        r"""VaultCreateParameters

        The model defined in huaweicloud sdk

        :param combined_order: 
        :type combined_order: :class:`huaweicloudsdkcbr.v1.CombinedOrder`
        """
        
        

        self._combined_order = None
        self.discriminator = None

        if combined_order is not None:
            self.combined_order = combined_order

    @property
    def combined_order(self):
        r"""Gets the combined_order of this VaultCreateParameters.

        :return: The combined_order of this VaultCreateParameters.
        :rtype: :class:`huaweicloudsdkcbr.v1.CombinedOrder`
        """
        return self._combined_order

    @combined_order.setter
    def combined_order(self, combined_order):
        r"""Sets the combined_order of this VaultCreateParameters.

        :param combined_order: The combined_order of this VaultCreateParameters.
        :type combined_order: :class:`huaweicloudsdkcbr.v1.CombinedOrder`
        """
        self._combined_order = combined_order

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VaultCreateParameters):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
